@@ -187,6 +187,11 @@ ScreenCastPortal::SourceType ScreenCastSession::types() const
     return m_types;
 }
 
+void ScreenCastSession::setPersistMode(ScreenCastPortal::PersistMode persistMode)
+{
+    m_persistMode = persistMode;
+}
+
 ScreenCastPortal::CursorModes ScreenCastSession::cursorMode() const
 {
     return m_cursorMode;
@@ -196,8 +201,6 @@ void ScreenCastSession::setOptions(const QVariantMap &options)
 {
     m_multipleSources = options.value(QStringLiteral("multiple")).toBool();
     m_cursorMode = ScreenCastPortal::CursorModes(options.value(QStringLiteral("cursor_mode")).toUInt());
-    m_persistMode = ScreenCastPortal::PersistMode(options.value("persist_mode").toUInt());
-    m_restoreData = options.value(QStringLiteral("restore_data"));
     m_types = ScreenCastPortal::SourceType(options.value(QStringLiteral("types")).toUInt());
 
     if (m_types == 0) {
@@ -220,6 +223,10 @@ RemoteDesktopSession::~RemoteDesktopSession()
 {
 }
 
+void RemoteDesktopSession::setOptions(const QVariantMap &options)
+{
+}
+
 RemoteDesktopPortal::DeviceTypes RemoteDesktopSession::deviceTypes() const
 {
     return m_deviceTypes;
